@@ -39,17 +39,17 @@
 
 #include <WebEngineViewer/ZoomActionMenu>
 
-#include <kactionmenu.h>
-#include <ktoolbarpopupaction.h>
+#include <KActionMenu>
+#include <KToolBarPopupAction>
 #include <QAction>
 #include <KToggleAction>
-#include <kactioncollection.h>
+#include <KActionCollection>
 #include "akregator_debug.h"
 #include <KLocalizedString>
 #include <QMenu>
 #include <QKeySequence>
-#include <kstandardshortcut.h>
-#include <kstandardaction.h>
+#include <KStandardShortcut>
+#include <KStandardAction>
 #include <kxmlguifactory.h>
 #include <KGuiItem>
 
@@ -210,7 +210,7 @@ void ActionManagerImpl::initPart()
     configure->setIcon(QIcon::fromTheme(QStringLiteral("configure")));
     connect(configure, &QAction::triggered, d->part, &Part::showOptions);
 
-    KStandardAction::configureNotifications(d->part, SLOT(showNotificationOptions()), d->actionCollection); // options_configure_notifications
+    KStandardAction::configureNotifications(d->part, &Part::showNotificationOptions, d->actionCollection); // options_configure_notifications
 }
 
 void ActionManagerImpl::initMainWidget(MainWidget *mainWidget)
