@@ -52,24 +52,24 @@
 #include "akregator-version.h"
 #include "unityservicemanager.h"
 #include <kio/filecopyjob.h>
-#include <knotifyconfigwidget.h>
-#include <kaboutdata.h>
-#include <kconfig.h>
-#include <kconfigdialog.h>
+#include <KNotifyConfigWidget>
+#include <KAboutData>
+#include <KConfig>
+#include <KConfigDialog>
 #include <QFileDialog>
-#include <kmessagebox.h>
+#include <KMessageBox>
 
 #include <QTemporaryFile>
 #include <QWebEngineSettings>
 #include <QSaveFile>
-#include <kservice.h>
+#include <KService>
 #include <kxmlguifactory.h>
 #include <KIO/StoredTransferJob>
 #include <KJobWidgets>
 #include <KPluginFactory>
 #include <KParts/Plugin>
 #include <KCMultiDialog>
-#include <kstandardaction.h>
+#include <KStandardAction>
 
 #include <QApplication>
 #include <QFile>
@@ -459,7 +459,13 @@ bool Part::writeToTextFile(const QString &data, const QString &filename) const
     }
     QTextStream stream(&file);
     stream.setCodec("UTF-8");
-    stream << data << endl;
+    stream << data
+          #if (QT_VERSION < QT_VERSION_CHECK(5, 15, 0))
+           << endl
+          #else
+           << Qt::endl
+          #endif
+              ;
     return file.commit();
 }
 
@@ -595,7 +601,7 @@ void Part::exportFile(const QUrl &url)
 
 void Part::fileImport()
 {
-    const QString filters = i18n("OPML Outlines (*.opml *.xml);;All Files (*)");
+    const QString filters = i18n("OPML Outlines (%1);;All Files (*)", QStringLiteral("*.opml *.xml"));
     const QUrl url = QFileDialog::getOpenFileUrl(m_mainWidget, QString(), QUrl(), filters);
     if (!url.isEmpty()) {
         importFile(url);
@@ -604,7 +610,7 @@ void Part::fileImport()
 
 void Part::fileExport()
 {
-    const QString filters = i18n("OPML Outlines (*.opml *.xml);;All Files (*)");
+    const QString filters = i18n("OPML Outlines (%1);;All Files (*)", QStringLiteral("*.opml *.xml"));
     const QUrl url = QFileDialog::getSaveFileUrl(m_mainWidget, QString(), QUrl(), filters);
 
     if (!url.isEmpty()) {
@@ -663,6 +669,10 @@ void Part::showOptions()
         m_dialog->addModule(QStringLiteral("akregator_config_browser"));
         m_dialog->addModule(QStringLiteral("akregator_config_advanced"));
         m_dialog->addModule(QStringLiteral("akregator_config_plugins"));
+#ifdef WITH_KUSERFEEDBACK
+        m_dialog->addModule(QStringLiteral("akregator_config_userfeedback"));
+#endif
+
     }
 
     m_dialog->show();
