@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2015-2019 Montel Laurent <montel@kde.org>
+   Copyright (C) 2015-2020 Laurent Montel <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -495,7 +495,7 @@ void ArticleViewerWebEngine::createViewerPluginToolManager(KActionCollection *ac
     mViewerPluginToolManager = new MessageViewer::ViewerPluginToolManager(parent, this);
     mViewerPluginToolManager->setActionCollection(ac);
     mViewerPluginToolManager->setPluginName(QStringLiteral("akregator"));
-    mViewerPluginToolManager->setServiceTypeName(QStringLiteral("Akregator/ViewerPlugin"));
+    mViewerPluginToolManager->setPluginDirectory(QStringLiteral("akregator/viewerplugin"));
     if (!mViewerPluginToolManager->initializePluginList()) {
         qCWarning(AKREGATOR_LOG) << " Impossible to initialize plugins";
     }
