@@ -24,6 +24,7 @@
 #include "storagedummyimpl.h"
 #include "feedstoragedummyimpl.h"
 
+#include <QDateTime>
 #include <QHash>
 #include <QString>
 #include <QStringList>
@@ -38,11 +39,11 @@ public:
     public:
         int unread;
         int totalCount;
-        int lastFetch;
+        QDateTime lastFetch;
         FeedStorage *feedStorage;
     };
 
-    void addEntry(const QString &url, int unread, int totalCount, int lastFetch)
+    void addEntry(const QString &url, int unread, int totalCount, const QDateTime &lastFetch)
     {
         Entry entry;
         entry.unread = unread;
@@ -52,7 +53,6 @@ public:
         feeds[url] = entry;
     }
 
-    QString tagSet;
     QString feedList;
     QHash<QString, Entry> feeds;
 };
@@ -63,6 +63,7 @@ StorageDummyImpl::StorageDummyImpl() : d(new StorageDummyImplPrivate)
 
 StorageDummyImpl::~StorageDummyImpl()
 {
+    close();
     delete d;
     d = nullptr;
 }
@@ -81,13 +82,11 @@ bool StorageDummyImpl::autoCommit() const
     return false;
 }
 
-bool StorageDummyImpl::close()
+void StorageDummyImpl::close()
 {
     for (QHash<QString, StorageDummyImplPrivate::Entry>::ConstIterator it = d->feeds.constBegin(); it != d->feeds.constEnd(); ++it) {
-        (*it).feedStorage->close();
         delete(*it).feedStorage;
     }
-    return true;
 }
 
 bool StorageDummyImpl::commit()
@@ -108,7 +107,7 @@ int StorageDummyImpl::unreadFor(const QString &url) const
 void StorageDummyImpl::setUnreadFor(const QString &url, int unread)
 {
     if (!d->feeds.contains(url)) {
-        d->addEntry(url, unread, unread, 0);
+        d->addEntry(url, unread, unread, QDateTime());
     } else {
         d->feeds[url].unread = unread;
     }
@@ -122,18 +121,18 @@ int StorageDummyImpl::totalCountFor(const QString &url) const
 void StorageDummyImpl::setTotalCountFor(const QString &url, int total)
 {
     if (!d->feeds.contains(url)) {
-        d->addEntry(url, 0, total, 0);
+        d->addEntry(url, 0, total, QDateTime());
     } else {
         d->feeds[url].totalCount = total;
     }
 }
 
-int StorageDummyImpl::lastFetchFor(const QString &url) const
+QDateTime StorageDummyImpl::lastFetchFor(const QString &url) const
 {
-    return d->feeds.contains(url) ? d->feeds[url].lastFetch : 0;
+    return d->feeds.contains(url) ? d->feeds[url].lastFetch : QDateTime();
 }
 
-void StorageDummyImpl::setLastFetchFor(const QString &url, int lastFetch)
+void StorageDummyImpl::setLastFetchFor(const QString &url, const QDateTime &lastFetch)
 {
     if (!d->feeds.contains(url)) {
         d->addEntry(url, 0, 0, lastFetch);
@@ -169,23 +168,6 @@ QStringList StorageDummyImpl::feeds() const
     return d->feeds.keys();
 }
 
-void StorageDummyImpl::add(Storage *source)
-{
-    QStringList feeds = source->feeds();
-    for (QStringList::ConstIterator it = feeds.constBegin(); it != feeds.constEnd(); ++it) {
-        FeedStorage *fa = archiveFor(*it);
-        fa->add(source->archiveFor(*it));
-    }
-}
-
-void StorageDummyImpl::clear()
-{
-    for (QHash<QString, StorageDummyImplPrivate::Entry>::ConstIterator it = d->feeds.constBegin(); it != d->feeds.constEnd(); ++it) {
-        delete(*it).feedStorage;
-    }
-    d->feeds.clear();
-}
-
 void StorageDummyImpl::storeFeedList(const QString &opmlStr)
 {
     d->feedList = opmlStr;
@@ -195,15 +177,5 @@ QString StorageDummyImpl::restoreFeedList() const
 {
     return d->feedList;
 }
-
-void StorageDummyImpl::storeTagSet(const QString &xmlStr)
-{
-    d->tagSet = xmlStr;
-}
-
-QString StorageDummyImpl::restoreTagSet() const
-{
-    return d->tagSet;
-}
 } // namespace Backend
 } // namespace Akregator
