@@ -38,7 +38,6 @@
 #include "utils.h"
 #include "feedretriever.h"
 #include "job/downloadfeediconjob.h"
-#include <syndication_version.h>
 #include <Syndication/Syndication>
 
 #include "akregator_debug.h"
@@ -102,6 +101,7 @@ public:
     QString m_htmlUrl;
     QString m_description;
     QString m_comment;
+    QString m_copyright;
 
     /** list of feed articles */
     QHash<QString, Article> articles;
@@ -157,6 +157,7 @@ Akregator::Feed *Feed::fromOPML(const QDomElement &e, Backend::Storage *storage)
 
     const QString htmlUrl = e.attribute(QStringLiteral("htmlUrl"));
     const QString description = e.attribute(QStringLiteral("description"));
+    const QString copyright = e.attribute(QStringLiteral("copyright"));
     const int fetchInterval = e.attribute(QStringLiteral("fetchInterval")).toInt();
     const ArchiveMode archiveMode = stringToArchiveMode(e.attribute(QStringLiteral("archiveMode")));
     const int maxArticleAge = e.attribute(QStringLiteral("maxArticleAge")).toUInt();
@@ -191,6 +192,7 @@ Akregator::Feed *Feed::fromOPML(const QDomElement &e, Backend::Storage *storage)
     feed->setTitle(title);
     feed->setFaviconInfo(faviconInfo);
     feed->setLogoInfo(logoInfo);
+    feed->setCopyright(copyright);
 
     feed->setXmlUrl(xmlUrl);
     feed->setCustomFetchIntervalEnabled(useCustomFetchInterval);
@@ -551,6 +553,8 @@ QDomElement Feed::toOPML(QDomElement parent, QDomDocument document) const
     el.setAttribute(QStringLiteral("maxArticleAge"), d->m_maxArticleAge);
     el.setAttribute(QStringLiteral("comment"), d->m_comment);
     el.setAttribute(QStringLiteral("maxArticleNumber"), d->m_maxArticleNumber);
+    el.setAttribute(QStringLiteral("copyright"), d->m_copyright);
+
     if (d->m_markImmediatelyAsRead) {
         el.setAttribute(QStringLiteral("markImmediatelyAsRead"), QStringLiteral("true"));
     }
@@ -792,7 +796,6 @@ void Feed::fetchCompleted(Syndication::Loader *l, Syndication::FeedPtr doc, Synd
 
     loadArticles(); // TODO: make me fly: make this delayed
 
-#if SYNDICATION_VERSION >= QT_VERSION_CHECK(5, 65, 0)
     if (!doc->icon().isNull() && !doc->icon()->url().isEmpty()) {
         loadFavicon(doc->icon()->url(), false);
         d->m_faviconInfo.width = doc->icon()->width();
@@ -800,9 +803,6 @@ void Feed::fetchCompleted(Syndication::Loader *l, Syndication::FeedPtr doc, Synd
     } else {
         loadFavicon(xmlUrl(), true);
     }
-#else
-    loadFavicon(xmlUrl(), true);
-#endif
     d->m_fetchErrorCode = Syndication::Success;
 
     if (!doc->image().isNull()) {
@@ -816,6 +816,7 @@ void Feed::fetchCompleted(Syndication::Loader *l, Syndication::FeedPtr doc, Synd
     }
 
     d->m_description = doc->description();
+    d->m_copyright = doc->copyright();
     d->m_htmlUrl = doc->link();
 
     appendArticles(doc);
@@ -848,7 +849,7 @@ void Feed::deleteExpiredArticles(ArticleDeleteJob *deleteJob)
 
     setNotificationMode(false);
 
-    QList<ArticleId> toDelete;
+    Akregator::ArticleIdList toDelete;
     const QString feedUrl = xmlUrl();
     const bool useKeep = Settings::doNotExpireImportantArticles();
 
@@ -863,6 +864,16 @@ void Feed::deleteExpiredArticles(ArticleDeleteJob *deleteJob)
     setNotificationMode(true);
 }
 
+QString Feed::copyright() const
+{
+    return d->m_copyright;
+}
+
+void Feed::setCopyright(const QString &copyright)
+{
+    d->m_copyright = copyright;
+}
+
 void Feed::setFavicon(const QIcon &icon)
 {
     d->m_favicon = icon;
