@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2016-2019 Montel Laurent <montel@kde.org>
+   Copyright (C) 2016-2020 Laurent Montel <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -88,21 +88,26 @@ QString GrantleeViewFormatter::formatFeed(Akregator::Feed *feed)
     feedObject.insert(QStringLiteral("feedImage"), feedImage);
 
     if (!feed->description().isEmpty()) {
-        QString feedDescription;
-        feedDescription = QStringLiteral("<div dir=\"%1\">").arg(mDirectionString);
+        QString feedDescription = QStringLiteral("<div dir=\"%1\">").arg(mDirectionString);
         feedDescription += i18n("<b>Description:</b> %1<br />", feed->description());
         feedDescription += QStringLiteral("</div>"); // /description
         feedObject.insert(QStringLiteral("feedDescription"), feedDescription);
     }
 
     if (!feed->htmlUrl().isEmpty()) {
-        QString feedHomePage;
-        feedHomePage = QStringLiteral("<div dir=\"%1\">").arg(mDirectionString);
+        QString feedHomePage = QStringLiteral("<div dir=\"%1\">").arg(mDirectionString);
         feedHomePage += i18n("<b>Homepage:</b> <a href=\"%1\">%1</a>", feed->htmlUrl());
         feedHomePage += QStringLiteral("</div>"); // / link
         feedObject.insert(QStringLiteral("feedHomePage"), feedHomePage);
     }
 
+    if (!feed->copyright().isEmpty()) {
+        QString feedCopyright = QStringLiteral("<div dir=\"%1\">").arg(mDirectionString);
+        feedCopyright += i18n("<b>Copyright:</b> %1</a>", feed->copyright());
+        feedCopyright += QStringLiteral("</div>");
+        feedObject.insert(QStringLiteral("feedCopyright"), feedCopyright);
+    }
+
     return render(feedObject);
 }
 
